#!/bin/sh -e

glibtoolize -f -c
aclocal --force
autoheader -f
autoconf -f
#cp -f $(dirname $(which automake))/../share/automake/mkinstalldirs ./
cp -f $(dirname $(which automake))/../share/gettext/config.rpath ./
automake -a -c --gnu --foreign
